@@ -6,6 +6,7 @@ import logging
 import re
 import time
 import uuid
+import pytz
 from collections import OrderedDict
 
 from wzdx.tools import date_tools, polygon_tools, wzdx_translator, cdot_geospatial_api
@@ -387,12 +388,18 @@ def create_rtdh_standard_msg(pd, isIncident):
                         date_tools.parse_datetime_from_iso_string)
     end_date = pd.get("properties/clearTime",
                       date_tools.parse_datetime_from_iso_string)
+
     if not end_date:
-        # Since there is no end date, assume still active, set end date in future (or 1 day after start date)
-        if start_date > datetime.datetime.utcnow():
-            end_date = start_date + datetime.timedelta(hours=24)
-        else:
-            end_date = datetime.datetime.utcnow() + datetime.timedelta(hours=24)
+        end_date = pd.get("properties/estimatedClearTime",
+                          date_tools.parse_datetime_from_iso_string)
+
+    now = datetime.datetime.utcnow().replace(tzinfo=pytz.utc)
+    if not end_date:
+        # Since there is no end date, assume still active, set end date in future (12 hours + n days until after current time)
+        end_date = start_date + datetime.timedelta(hours=12)
+
+        while end_date < now:
+            end_date = start_date + datetime.timedelta(days=1)
 
     event_type, types_of_work = map_event_type(
         pd.get("properties/type", default=""))
